/*--------------------------------------------------------------------------*/
/* themes                                                                   */
/*--------------------------------------------------------------------------*/

#ifndef __MY_THEME_H
#define __MY_THEME_H

/*--------------------------------------------------------------------------*/
/* structures                                                               */
/*--------------------------------------------------------------------------*/

typedef struct {
   char *name;                          /* name == NULL marks end of list */
   char *descr;
   char *author;
} THEME;

/*--------------------------------------------------------------------------*/
/* functions                                                                */
/*--------------------------------------------------------------------------*/

void theme_init(void (*_progress_func)(char *msg, float progress));
void theme_select(char *name);
THEME *theme_get_themes(void);

#endif /* __MY_THEME_H */
